@@ -34,14 +34,14 @@
  *
  * Reset to zero each major version
  */
-#define LIBOBS_API_MINOR_VER 1
+#define LIBOBS_API_MINOR_VER 2
 
 /*
  * Increment if backward-compatible bug fix
  *
  * Reset to zero each major or minor version
  */
-#define LIBOBS_API_PATCH_VER 2
+#define LIBOBS_API_PATCH_VER 0
 
 #define MAKE_SEMANTIC_VERSION(major, minor, patch) \
 	((major << 24) | (minor << 16) | patch)
@@ -62,4 +62,4 @@
 #define OBS_BETA 0
 #endif
 
-#define OBS_INSTALL_DATA_PATH OBS_INSTALL_PREFIX OBS_DATA_PATH
+#define OBS_INSTALL_DATA_PATH OBS_INSTALL_PREFIX "/" OBS_DATA_PATH
